devicesinlan - Mariano Muñoz

# NAME

devicesinlan: Busca todos los dispositivos de tu LAN. Después, puedes establecer alias a tus dispositivos conocidos para detectar dispositivos extraños en tu red.

# SYNOPSIS

devicesinlan [--help] [--version] [--debug DEBUG] [ --interface | --add | --remove | --list | --load | --save | --reset ]

# DESCRIPCIÓN

If you launch DevicesInLan without parameters a console wizard is launched.

Además puedes usar uno de estos parámetros.

--interface

Escanea la red del interfaz pasado como parámetro y lista los dispositivos detectados.

Si un dispositivo no es conocido, se mostrará en rojo. Los dispositivos verdes son dispositivos confiables.

--add

Permite añadir un dispositivo conocido desde consola.

--remove

Permite borrar un dispositivo conocido desde consola.

--list

Muestra todos los dispositivos conocidos de la base de datos desde consola.

--load

Carga una lista de dispositivos conocidos en formato xml.

--save

Graba la lista de dispositivos conocidos a un fichero xml.

--debug

Gives debugging information when running DevicesInLAN. It's deactivated by default

The parameter can take this options: CRITICAL, ERROR, WARNING, INFO, DEBUG.

--reset

Borra todos los dispositivos conocidos.

Created with libmangenerator at 2019-08-03